@@ -1,12 +1,12 @@
 # coding: utf-8
 import numpy as np
 
-lx =   0.732813006922696
-hy =   0.792836654487448
-oz =   -6.400328302740263E-002
-hz =  0.512026264219221
-mz =  0.165996716972597
-lz = -0.567651708900964
+lx =   0.732813006922696 / 10
+hy =   0.792836654487448 / 10 
+oz =   -6.400328302740263E-002 / 10
+hz =  0.512026264219221 / 10
+mz =  0.165996716972597 / 10
+lz = -0.567651708900964 / 10
 
 sites = np.array([[0,  0,  oz],
                   [0,  hy, hz],
